/*****************************************************************************/
/*  DibPunto - Conversor de ascii a dxf                                      */
/*                                                                           */
/*  Copyright (C) 2011 Rallaz, rallazz@gmail.com                             */
/*                                                                           */
/*  This library is free software, licensed under the terms of the GNU       */
/*  General Public License as published by the Free Software Foundation,     */
/*  either version 3 of the License, or (at your option) any later version.  */
/*  You should have received a copy of the GNU General Public License        */
/*  along with this program.  If not, see <http://www.gnu.org/licenses/>.    */
/*****************************************************************************/

#include "dibpunto.h"
#include <QGridLayout>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QPushButton>
#include <QPainter>
#include <QFormLayout>
#include <QEvent>
#include <QPicture>
#include <QFileDialog>
#include <QSettings>
#include <math.h>
#include <QMessageBox>

#define POINT 12

imgLabel::imgLabel(QWidget * parent, Qt::WindowFlags f) :
    QLabel(parent, f)
{
    posimage = new QPicture;
    posimage->setBoundingRect(QRect(0,0,POINT*8,POINT*8));
    currPos = DPT::N;
    drawImage();
    setPicture(*posimage);
}

void imgLabel::drawImage()
{
    int a1, a2, a3, a4;
    int b1, b2, b3, b4;
    QPainter painter;
    painter.begin(posimage);
    painter.fillRect ( 0, 0, POINT*8,POINT*8, Qt::black );
    a1 = POINT*1.75;
    a2 = POINT*3.5;
    a3 = POINT*5.25;
    a4 = POINT*6;
    painter.fillRect ( a1, a1, POINT, POINT, Qt::white );//NO
    painter.fillRect ( a2, POINT, POINT, POINT, Qt::white );//N
    painter.fillRect ( POINT, a2, POINT, POINT, Qt::white );//O
    painter.fillRect ( a3, a1, POINT, POINT, Qt::white );//NE
    painter.fillRect ( a1, a3, POINT, POINT, Qt::white );//SO
    painter.fillRect ( a3, a3, POINT, POINT, Qt::white );//SE
    painter.fillRect ( a4, a2, POINT, POINT, Qt::white );//E
    painter.fillRect ( a2, a4, POINT, POINT, Qt::white );//S
    painter.setPen ( Qt::white );
    b1 = POINT*3.2;
    b2 = POINT*3.6;
    b3 = POINT*4;
    b4 = POINT*4.4;
    painter.drawLine ( b2, b2, b4, b2 );
    painter.drawLine ( b2, b2, b2, b4 );
    painter.drawLine ( b4, b2, b4, b4 );
    painter.drawLine ( b2, b4, b4, b4 );
    b4 = POINT*4.8;
    painter.drawLine ( b1, b3, b4, b3 );
    painter.drawLine ( b3, b1, b3, b4 );

    switch (currPos) {
    case DPT::NO:
        a2 = a1 = POINT*1.75;
        break;
    case DPT::O:
        a1 = POINT;
        a2 = POINT*3.5;
        break;
    case DPT::NE:
        a1 = POINT*5.25;
        a2 = POINT*1.75;
        break;
    case DPT::SO:
        a1 = POINT*1.75;
        a2 = POINT*5.25;
        break;
    case DPT::SE:
        a2 = a1 = POINT*5.25;
        break;
    case DPT::E:
        a1 = POINT*6;
        a2 = POINT*3.5;
        break;
    case DPT::S:
        a1 = POINT*3.5;
        a2 = POINT*6;
        break;
    default: //N
        a1 = POINT*3.5;
        a2 = POINT;
    }
    painter.fillRect ( a1, a2, POINT, POINT, Qt::red );
    painter.end();
    update ();
}

void imgLabel::changePos(int x, int y)
{
    if (x < POINT*3.1) {
        if (y < POINT*3.1) { setPos(DPT::NO); }
        else if (y < POINT*4.9) { setPos(DPT::O); }
        else { setPos(DPT::SO); }

    } else if (x < POINT*4.9) {
        if (y < POINT*4) { setPos(DPT::N); }
        else { setPos(DPT::S); }

    } else {
        if (y < POINT*3.1) { setPos(DPT::NE); }
        else if (y < POINT*4.9) { setPos(DPT::E); }
        else { setPos(DPT::SE); }
    }
}

void imgLabel::setPos(DPT::txtposition pos)
{
    currPos = pos;
    drawImage();
}

void imgLabel::mouseReleaseEvent(QMouseEvent *event)
 {
    if (event->button() == Qt::LeftButton) {
        changePos(event->x(), event->y());
     } else {
         QLabel::mousePressEvent(event);
     }
 }
 
/*****************************/
pointBox::pointBox(const QString & title, const QString & label, QWidget * parent ) :
    QGroupBox(title, parent)
{
    rb = new QRadioButton(label);
    vbox = new QVBoxLayout;
    vbox->addWidget(rb);
    QLabel *but = new QLabel(tr("Layer:"));
    layedit = new QLineEdit();
    QHBoxLayout *lolayer = new QHBoxLayout;
    lolayer->addWidget(but);
    lolayer->addWidget(layedit);
    vbox->addLayout(lolayer);
    setLayout(vbox);
}
void pointBox::setInLayout(QLayout *lo)
{
    vbox->addLayout(lo);
}
pointBox::~pointBox()
{

}
/*****************************/
textBox::textBox(const QString & title, const QString & label, QWidget * parent) :
    pointBox(title, label, parent)
{
    combostyle = new QComboBox();
    QStringList txtstyles;
     txtstyles << "txt" << "simplex" << "romans";
    combostyle->addItems(txtstyles);
    QDoubleValidator *val = new QDoubleValidator(0);
    val->setBottom ( 0.0 );
    heightedit = new QLineEdit();
    heightedit->setValidator(val);
    sepedit = new QLineEdit();
    sepedit->setValidator(val);

    QFormLayout *flo = new QFormLayout;
    flo->addRow( tr("Style:"), combostyle);
    flo->addRow( tr("Heigth:"), heightedit);
    flo->addRow( tr("Separation"), sepedit);
//    posimage.fill(Qt::black);
    img = new imgLabel();
    QHBoxLayout *loimage = new QHBoxLayout;
loimage->addLayout(flo);
loimage->addWidget(img);

    setInLayout(loimage);
}
/*void textBox::setPos(DPT::txtposition)
{
img->setPos();
}*/
textBox::~textBox()
{

}


/*****************************/
dibPunto::dibPunto(QWidget *parent) :
    QWidget(parent)
{
    QStringList txtformats;

    QGridLayout *mainLayout = new QGridLayout;
//readSettings();

QPushButton *filebut = new QPushButton(tr("File..."));
fileedit = new QLineEdit();
QHBoxLayout *lofile = new QHBoxLayout;
lofile->addWidget(filebut);
lofile->addWidget(fileedit);
mainLayout->addLayout(lofile, 0, 0);

QLabel *formatlabel = new QLabel(tr("Format:"));
formatedit = new QComboBox();
     txtformats << tr("Space Separator") << tr("Tab Separator") << tr("Comma Separator") << tr("*.odb for Psion 2");
//     txtformats << "Separador espacio" << "Separador tabulación" << "Separador coma" <<"*.odb de Psion 2";
    formatedit->addItems(txtformats);
QHBoxLayout *loformat = new QHBoxLayout;
loformat->addWidget(formatlabel);
loformat->addWidget(formatedit);
mainLayout->addLayout(loformat, 0, 1);

pt2d = new pointBox(tr("2D Point"),tr("Draw 2D Point"));
pt3d = new pointBox(tr("3D Point"),tr("Draw 3D Point"));
ptnumber = new textBox(tr("Point Number"),tr("Draw point number"));
ptelev = new textBox(tr("Point Elevation"),tr("Draw point elevation"));
ptcode = new textBox(tr("Point Code"),tr("Draw point code"));
    ptnumber->setPos(DPT::NO);

QVBoxLayout *lo2d3d = new QVBoxLayout;

lo2d3d->addWidget(pt2d);
lo2d3d->addWidget(pt3d);
mainLayout->addLayout(lo2d3d, 1, 0);

mainLayout->addWidget(ptnumber, 1, 1);
mainLayout->addWidget(ptelev, 2, 0);
mainLayout->addWidget(ptcode, 2, 1);

QHBoxLayout *loaccept = new QHBoxLayout;
QPushButton *acceptbut = new QPushButton(tr("Accept"));
loaccept->addStretch();
loaccept->addWidget(acceptbut);
mainLayout->addLayout(loaccept, 3, 0);

QPushButton *cancelbut = new QPushButton(tr("Close"));
QHBoxLayout *locancel = new QHBoxLayout;
locancel->addWidget(cancelbut);
locancel->addStretch();
mainLayout->addLayout(locancel, 3, 1);

setLayout(mainLayout);
//pt2d->setAlignment (Qt::AlignLeft);
    readSettings();

connect(cancelbut, SIGNAL(clicked()), this, SLOT(close()));
connect(acceptbut, SIGNAL(clicked()), this, SLOT(procesFile()));
connect(filebut, SIGNAL(clicked()), this, SLOT(dptFile()));
}
//void	clicked ( bool checked = false )
void dibPunto::dptFile()
{
    QString fileName = QFileDialog::getOpenFileName(this, tr("Select file"));
    fileedit->setText(fileName);
//    close();
}
bool dibPunto::failGUI(QString *msg)
{
    if (pt2d->checkOn() == true) {
        if (pt2d->getLayer().isEmpty()) {msg->insert(0, tr("Point 2D layer is empty")); return true;}
    }
    if (pt3d->checkOn() == true) {
        if (pt3d->getLayer().isEmpty()) {msg->insert(0, tr("Point 3D layer is empty")); return true;}
    }
    if (ptelev->checkOn() == true) {
        if (ptelev->getLayer().isEmpty()) {msg->insert(0, tr("Point elevation layer is empty")); return true;}
        if (ptelev->getHeightStr().isEmpty()) {msg->insert(0, tr("Point elevation height is empty")); return true;}
        if (ptelev->getSeparationStr().isEmpty()) {msg->insert(0, tr("Point elevation separation is empty")); return true;}
    }
    if (ptnumber->checkOn() == true) {
        if (ptnumber->getLayer().isEmpty()) {msg->insert(0, tr("Point number layer is empty")); return true;}
        if (ptnumber->getHeightStr().isEmpty()) {msg->insert(0, tr("Point number height is empty")); return true;}
        if (ptnumber->getSeparationStr().isEmpty()) {msg->insert(0, tr("Point number separation is empty")); return true;}
    }
    if (ptcode->checkOn() == true) {
        if (ptcode->getLayer().isEmpty()) {msg->insert(0, tr("Point code layer is empty")); return true;}
        if (ptcode->getHeightStr().isEmpty()) {msg->insert(0, tr("Point code height is empty")); return true;}
        if (ptcode->getSeparationStr().isEmpty()) {msg->insert(0, tr("Point code separation is empty")); return true;}
    }
    return false;
}

void dibPunto::procesFile()
{
    QString outname, sep, errmsg;
//    QStringList data;
    errmsg.clear();
    if (failGUI(&errmsg)) {
        QMessageBox::critical ( this, "DibPunto", errmsg );
        errmsg.clear();
        return;
    }
//Warning, can change ading or reordering "formatedit"
    switch (formatedit->currentIndex()) {
    case 0:
        sep = " ";
        break;
    case 2:
        sep = ",";
        break;
    default:
        sep = "\t";
    }
    if (!QFile::exists(fileedit->text()) ) {
        QMessageBox::critical ( this, "DibPunto", QString(tr("The file %1 not exist")).arg(fileedit->text()) );
        return;
    }
    QFile infile(fileedit->text());
    if (!infile.open(QIODevice::ReadOnly | QIODevice::Text)) {
        QMessageBox::critical ( this, "DibPunto", QString(tr("Can't open the file %1")).arg(fileedit->text()) );
         return;
    }
    QFileInfo info1(fileedit->text());
    outname = info1.canonicalPath() + QString("/") + info1.completeBaseName() + QString(".dxf");
    if (QFile::exists(outname) ) {
        int result = QMessageBox::question ( this, "DibPunto", QString(tr("The file %1 exist,\noverwrite it?")).arg(outname),
                                             QMessageBox::Yes | QMessageBox::No );
        if (result == QMessageBox::No)
            return;
    }
    QFile outfile(outname);
    if (!outfile.open(QIODevice::WriteOnly | QIODevice::Text)) {
        QMessageBox::critical ( this, "DibPunto", QString(tr("Can't open the file %1")).arg(outname) );
         return;
    }
//Warning, can change ading or reordering "formatedit"
    if (formatedit->currentIndex() == 3)
        procesfileODB(&infile, sep);
    else
        procesfileNormal(&infile, sep);
    infile.close ();

    outfile.write ( "  0\nSECTION\n  2\nTABLES\n  0\nTABLE\n");
    outfile.write ( "  2\nSTYLE\n100\nAcDbSymbolTable\n 70\n     3\n");
    if (ptelev->checkOn() == true) {
        outfile.write ( "  0\nSTYLE\n100\nAcDbSymbolTableRecord\n100\nAcDbTextStyleTableRecord\n  2\n");
        outfile.write ( ptelev->getStyleStr().toLatin1());
        outfile.write ( "\n 70\n     0\n 40\n0.0\n 41\n1.0\n 50\n0.0\n 71\n     0\n 42\n1.0\n  3\n");
        outfile.write ( ptelev->getStyleStr().toLatin1());
        outfile.write ( ".shx\n  4\n\n");
    }
    if (ptnumber->checkOn() == true) {
        outfile.write ( "  0\nSTYLE\n100\nAcDbSymbolTableRecord\n100\nAcDbTextStyleTableRecord\n  2\n");
        outfile.write ( ptnumber->getStyleStr().toLatin1());
        outfile.write ( "\n 70\n     0\n 40\n0.0\n 41\n1.0\n 50\n0.0\n 71\n     0\n 42\n1.0\n  3\n");
        outfile.write ( ptnumber->getStyleStr().toLatin1());
        outfile.write ( ".shx\n  4\n\n");
    }
    if (ptcode->checkOn() == true) {
        outfile.write ( "  0\nSTYLE\n100\nAcDbSymbolTableRecord\n100\nAcDbTextStyleTableRecord\n  2\n");
        outfile.write ( ptcode->getStyleStr().toLatin1());
        outfile.write ( "\n 70\n     0\n 40\n0.0\n 41\n1.0\n 50\n0.0\n 71\n     0\n 42\n1.0\n  3\n");
        outfile.write ( ptcode->getStyleStr().toLatin1());
        outfile.write ( ".shx\n  4\n\n");
    }

    outfile.write ( "  0\nENDTAB\n  0\nENDSEC\n");
    outfile.write ( "  0\nSECTION\n  2\nENTITIES\n");
    if (pt2d->checkOn() == true)
        draw2D(&outfile);
    if (pt3d->checkOn() == true)
        draw3D(&outfile);
    if (ptelev->checkOn() == true)
        drawElev(&outfile);
    if (ptnumber->checkOn() == true)
        drawNumber(&outfile);
    if (ptcode->checkOn() == true)
        drawCode(&outfile);
    outfile.write ( "  0\nENDSEC\n  0\nEOF");
    outfile.close ();
}

void dibPunto::draw2D(QFile* file)
{
    for (int i = 0; i < dataList.size(); ++i) {
        pointData *pd = dataList.at(i);
        if (!pd->x.isEmpty() && !pd->y.isEmpty()){
            file->write ( "  0\nPOINT\n100\nAcDbEntity\n  8\n");
            file->write ( pt2d->getLayer().toLatin1());
            file->write ( "\n100\nAcDbPoint\n 10\n");
            file->write ( pd->x.toLatin1());
            file->write ( "\n 20\n");
            file->write ( pd->y.toLatin1());
            file->write ( "\n 30\n0.0\n");
        }
    }
}
void dibPunto::draw3D(QFile* file)
{
    for (int i = 0; i < dataList.size(); ++i) {
        pointData *pd = dataList.at(i);
        if (!pd->x.isEmpty() && !pd->y.isEmpty()){
            file->write ( "  0\nPOINT\n100\nAcDbEntity\n  8\n");
            file->write ( pt3d->getLayer().toLatin1());
            file->write ( "\n100\nAcDbPoint\n 10\n");
            file->write ( pd->x.toLatin1());
            file->write ( "\n 20\n");
            file->write ( pd->y.toLatin1());
            file->write ( "\n 30\n");
            if (pd->z.isEmpty()) file->write ( "0.0");
            file->write ( pd->z.toLatin1());
            file->write ( "\n");
        }
    }
}
void dibPunto::drawNumber(QFile* file)
{
    QString ori,xstr,ystr;
    xstr = "\n100\nAcDbText\n 10\n0.0\n 20\n0.0\n 30\n0.0\n 11\n";
    ystr = "\n 21\n";
    double inc, incx, incy, newx, newy;
    incx = incy = ptnumber->getSeparation();
    inc = sqrt(incx*incx/2);
    switch (ptnumber->getPosition()) {
    case DPT::NO:
        ori = "\n 72\n     2\n 73\n     0\n";
        incx = -1.0*inc; incy = inc;
        break;
    case DPT::O:
        ori = "\n 72\n     2\n 73\n     2\n";
        incx = -1.0*incx; incy = 0.0;
        break;
    case DPT::NE:
        xstr = "\n100\nAcDbText\n 10\n";
        ystr = "\n 20\n";
        ori = "\n 72\n     0\n 73\n     0\n";
        incx = inc; incy = inc;
        break;
    case DPT::SO:
        ori = "\n 72\n     2\n 73\n     3\n";
        incx = -1.0*inc; incy = -1.0*inc;
        break;
    case DPT::SE:
        ori = "\n 72\n     0\n 73\n     3\n";
        incx = inc; incy = -1.0*inc;
        break;
    case DPT::E:
        ori = "\n 72\n     0\n 73\n     2\n";
        incy = 0.0;
        break;
    case DPT::S:
        ori = "\n 72\n     1\n 73\n     3\n";
        incx = 0.0; incy = -1.0*incy;
        break;
    default: //N
        ori = "\n 72\n     1\n 73\n     0\n";
        incx = 0.0;
    }

    for (int i = 0; i < dataList.size(); ++i) {
        pointData *pd = dataList.at(i);
        if (!pd->x.isEmpty() && !pd->y.isEmpty() && !pd->number.isEmpty()){
            file->write ( "  0\nTEXT\n100\nAcDbEntity\n  8\n");
            file->write ( ptnumber->getLayer().toLatin1());
            file->write ( xstr.toLatin1());
//            file->write ( "\n100\nAcDbText\n 11\n");
            newx = pd->x.toDouble() + incx;
            file->write ( QByteArray::number(newx, 'f'));
            file->write ( ystr.toLatin1());
//            file->write ( "\n 21\n");
            newy = pd->y.toDouble() + incy;
            file->write ( QByteArray::number(newy, 'f'));
//            file->write ( "\n 31\n0.0\n 40\n");
            file->write ( "\n 40\n");
            file->write ( ptnumber->getHeightStr().toLatin1());
            file->write ( "\n  1\n");
            file->write ( pd->number.toLatin1());
            file->write ( "\n  7\n");
            file->write ( ptnumber->getStyleStr().toLatin1());
            file->write ( ori.toLatin1());
//            file->write ( "\n");
        }
    }
}

void dibPunto::drawElev(QFile* file)
{
    QString ori,xstr,ystr;
    xstr = "\n100\nAcDbText\n 10\n0.0\n 20\n0.0\n 30\n0.0\n 11\n";
    ystr = "\n 21\n";
    double inc, incx, incy, newx, newy;
    incx = incy = ptnumber->getSeparation();
    inc = sqrt(incx*incx/2);
    switch (ptelev->getPosition()) {
    case DPT::NO:
        ori = "\n 72\n     2\n 73\n     0\n";
        incx = -1.0*inc; incy = inc;
        break;
    case DPT::O:
        ori = "\n 72\n     2\n 73\n     2\n";
        incx = -1.0*incx; incy = 0.0;
        break;
    case DPT::NE:
        xstr = "\n100\nAcDbText\n 10\n";
        ystr = "\n 20\n";
        ori = "\n 72\n     0\n 73\n     0\n";
        incx = incy = inc;
        break;
    case DPT::SO:
        ori = "\n 72\n     2\n 73\n     3\n";
        incx = -1.0*inc; incy = -1.0*inc;
        break;
    case DPT::SE:
        ori = "\n 72\n     0\n 73\n     3\n";
        incx = inc; incy = -1.0*inc;
        break;
    case DPT::E:
        ori = "\n 72\n     0\n 73\n     2\n";
        incy = 0.0;
        break;
    case DPT::S:
        ori = "\n 72\n     1\n 73\n     3\n";
        incx = 0.0; incy = -1.0*incy;
        break;
    default: //N
        ori = "\n 72\n     1\n 73\n     0\n";
        incx = 0.0;
    }

    for (int i = 0; i < dataList.size(); ++i) {
        pointData *pd = dataList.at(i);
        if (!pd->x.isEmpty() && !pd->x.isEmpty() && !pd->z.isEmpty()){
            file->write ( "  0\nTEXT\n100\nAcDbEntity\n  8\n");
            file->write ( ptelev->getLayer().toLatin1());
            file->write ( xstr.toLatin1());
//            file->write ( "\n100\nAcDbText\n 11\n");
            newx = pd->x.toDouble() + incx;
            file->write ( QByteArray::number(newx, 'f'));
            file->write ( ystr.toLatin1());
//            file->write ( "\n 21\n");
            newy = pd->y.toDouble() + incy;
            file->write ( QByteArray::number(newy, 'f'));
//            file->write ( "\n 31\n0.0\n 40\n");
            file->write ( "\n 40\n");
            file->write ( ptelev->getHeightStr().toLatin1());
            file->write ( "\n  1\n");
            file->write ( pd->z.toLatin1());
            file->write ( "\n  7\n");
            file->write ( ptelev->getStyleStr().toLatin1());
            file->write ( ori.toLatin1());
//            file->write ( "\n");
        }
    }
}
void dibPunto::drawCode(QFile* file)
{
    QString ori,xstr,ystr;
    xstr = "\n100\nAcDbText\n 10\n0.0\n 20\n0.0\n 30\n0.0\n 11\n";
    ystr = "\n 21\n";
    double inc, incx, incy, newx, newy;
    incx = incy = ptnumber->getSeparation();
    inc = sqrt(incx*incx/2);
    switch (ptcode->getPosition()) {
    case DPT::NO:
        ori = "\n 72\n     2\n 73\n     0\n";
        incx = -1.0*inc; incy = inc;
        break;
    case DPT::O:
        ori = "\n 72\n     2\n 73\n     2\n";
        incx = -1.0*incx; incy = 0.0;
        break;
    case DPT::NE:
        xstr = "\n100\nAcDbText\n 10\n";
        ystr = "\n 20\n";
        ori = "\n 72\n     0\n 73\n     0\n";
        incx = incy = inc;
        break;
    case DPT::SO:
        ori = "\n 72\n     2\n 73\n     3\n";
        incx = -1.0*inc; incy = -1.0*inc;
        break;
    case DPT::SE:
        ori = "\n 72\n     0\n 73\n     3\n";
        incx = inc; incy = -1.0*inc;
        break;
    case DPT::E:
        ori = "\n 72\n     0\n 73\n     2\n";
        incy = 0.0;
        break;
    case DPT::S:
        ori = "\n 72\n     1\n 73\n     3\n";
        incx = 0.0; incy = -1.0*incy;
        break;
    default: //N
        ori = "\n 72\n     1\n 73\n     0\n";
        incx = 0.0;
    }

    for (int i = 0; i < dataList.size(); ++i) {
        pointData *pd = dataList.at(i);
        if (!pd->x.isEmpty() && !pd->x.isEmpty() && !pd->code.isEmpty()){
            file->write ( "  0\nTEXT\n100\nAcDbEntity\n  8\n");
            file->write ( ptcode->getLayer().toLatin1());
            file->write ( xstr.toLatin1());
//            file->write ( "\n100\nAcDbText\n 11\n");
            newx = pd->x.toDouble() + incx;
            file->write ( QByteArray::number(newx, 'f'));
            file->write ( ystr.toLatin1());
//            file->write ( "\n 21\n");
            newy = pd->y.toDouble() + incy;
            file->write ( QByteArray::number(newy, 'f'));
//            file->write ( "\n 31\n0.0\n 40\n");
            file->write ( "\n 40\n");
            file->write ( ptcode->getHeightStr().toLatin1());
            file->write ( "\n  1\n");
            file->write ( pd->code.toLatin1());
            file->write ( "\n  7\n");
            file->write ( ptcode->getStyleStr().toLatin1());
            file->write ( ori.toLatin1());
//            file->write ( "\n");
        }
    }
}

    void dibPunto::procesfileODB(QFile* file, QString sep)
{
    QStringList data;
    pointData *pd;

    while (!file->atEnd()) {
        QString line = file->readLine();
        line.remove ( line.size()-2, 1);
        data = line.split(sep);
        pd = new pointData;
        int i = 0;
        int j = data.size();
        if (i<j && data.at(i).compare("4")==0 ){
            i = i+2;
            if (i<j) pd->x = data.at(i); else pd->x = QString();
            i++;
            if (i<j) pd->y = data.at(i); else pd->y = QString();
            i++;
            if (i<j) pd->z = data.at(i); else pd->z = QString();
            i++;
            if (i<j) pd->number = data.at(i); else pd->number = QString();
            i++;
            if (i<j) pd->code = data.at(i); else pd->code = QString();
        }
        dataList.append(pd);
    }

}
void dibPunto::procesfileNormal(QFile* file, QString sep)
{
    //    QString outname, sep;
    QStringList data;
    pointData *pd;
    while (!file->atEnd()) {
        QString line = file->readLine();
        line.remove ( line.size()-1, 1);
        data = line.split(sep);
        pd = new pointData;
        int i = 0;
        int j = data.size();
        if (i<j) pd->number = data.at(i); else pd->number = QString ();
        i++;
        if (i<j) pd->x = data.at(i); else pd->x = QString();
        i++;
        if (i<j) pd->y = data.at(i); else pd->y = QString();
        i++;
        if (i<j) pd->z = data.at(i); else pd->z = QString();
        i++;
        if (i<j) pd->code = data.at(i); else pd->code = QString ();
        dataList.append(pd);
    }
}

dibPunto::~dibPunto()
{
    while (!dataList.isEmpty())
         delete dataList.takeFirst();
}
void dibPunto::closeEvent(QCloseEvent *event)
 {
    writeSettings();
    QWidget::closeEvent(event);
 }


void dibPunto::readSettings()
 {
    QString str;
    QSettings settings(QSettings::IniFormat, QSettings::UserScope, "Rallaz", "dibpunto");
    QPoint pos = settings.value("pos", QPoint(200, 200)).toPoint();
    QSize size = settings.value("size", QSize(500,300)).toSize();
    str = settings.value("lastfile").toString();
    fileedit->setText(str);
    formatedit->setCurrentIndex( settings.value("format", 0).toInt() );
    pt2d->setCheck( settings.value("draw2d", false).toBool() );
    str = settings.value("layer2d").toString();
    pt2d->setLayer(str);
    pt3d->setCheck( settings.value("draw3d", false).toBool() );
    str = settings.value("layer3d").toString();
    pt3d->setLayer(str);
    ptelev->setCheck( settings.value("drawelev", false).toBool() );
    str = settings.value("layerelev").toString();
    ptelev->setLayer(str);
    ptnumber->setCheck( settings.value("drawnumber", false).toBool() );
    str = settings.value("layernumber").toString();
    ptnumber->setLayer(str);
    ptcode->setCheck( settings.value("drawcode", false).toBool() );
    str = settings.value("layercode").toString();
    ptcode->setLayer(str);
    ptelev->setStyleIdx( settings.value("styleelev", 0).toInt() );
    ptnumber->setStyleIdx( settings.value("stylenumber", 0).toInt() );
    ptcode->setStyleIdx(settings.value("stylecode", 0).toInt() );
    ptelev->setHeight( settings.value("heightelev", 0.5).toDouble() );
    ptnumber->setHeight( settings.value("heightnumber", 0.5).toDouble() );
    ptcode->setHeight( settings.value("heightcode", 0.5).toDouble() );
    ptelev->setSeparation( settings.value("separationelev", 0.3).toDouble() );
    ptnumber->setSeparation( settings.value("separationnumber", 0.3).toDouble() );
    ptcode->setSeparation( settings.value("separationcode", 0.3).toDouble() );
    ptelev->setPosition( static_cast<DPT::txtposition>( settings.value("positionelev", DPT::S).toInt() ) );
    ptnumber->setPosition( static_cast<DPT::txtposition>( settings.value("positionnumber", DPT::N).toInt() ) );
    ptcode->setPosition( static_cast<DPT::txtposition>( settings.value("positioncode", DPT::E).toInt() ) );
    resize(size);
    move(pos);
 }
void dibPunto::writeSettings()
 {
    QSettings settings(QSettings::IniFormat, QSettings::UserScope, "Rallaz", "dibpunto");
    settings.setValue("pos", pos());
    settings.setValue("size", size());
    settings.setValue("lastfile", fileedit->text());
    settings.setValue("format", formatedit->currentIndex());
    settings.setValue("draw2d", pt2d->checkOn());
    settings.setValue("draw3d", pt3d->checkOn());
    settings.setValue("drawelev", ptelev->checkOn());
    settings.setValue("drawnumber", ptnumber->checkOn());
    settings.setValue("drawcode", ptcode->checkOn());
    settings.setValue("layer2d", pt2d->getLayer());
    settings.setValue("layer3d", pt3d->getLayer());
    settings.setValue("layerelev", ptelev->getLayer());
    settings.setValue("layernumber", ptnumber->getLayer());
    settings.setValue("layercode", ptcode->getLayer());
    settings.setValue("styleelev", ptelev->getStyleIdx());
    settings.setValue("stylenumber", ptnumber->getStyleIdx());
    settings.setValue("stylecode", ptcode->getStyleIdx());
    settings.setValue("heightelev", ptelev->getHeightStr());
    settings.setValue("heightnumber", ptnumber->getHeightStr());
    settings.setValue("heightcode", ptcode->getHeightStr());
    settings.setValue("separationelev", ptelev->getSeparationStr());
    settings.setValue("separationnumber", ptnumber->getSeparationStr());
    settings.setValue("separationcode", ptcode->getSeparationStr());
    settings.setValue("positionelev", ptelev->getPosition());
    settings.setValue("positionnumber", ptnumber->getPosition());
    settings.setValue("positioncode", ptcode->getPosition());
 }
